@@ -6,9 +6,9 @@ Type annotations for kinesisanalytics service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_kinesisanalytics.type_defs import AddApplicationCloudWatchLoggingOptionRequestTypeDef
+    from mypy_boto3_kinesisanalytics.type_defs import AddApplicationCloudWatchLoggingOptionRequestRequestTypeDef
 
-    data: AddApplicationCloudWatchLoggingOptionRequestTypeDef = {...}
+    data: AddApplicationCloudWatchLoggingOptionRequestRequestTypeDef = {...}
     ```
 """
 import sys
@@ -24,11 +24,11 @@ else:
 
 
 __all__ = (
-    "AddApplicationCloudWatchLoggingOptionRequestTypeDef",
-    "AddApplicationInputProcessingConfigurationRequestTypeDef",
-    "AddApplicationInputRequestTypeDef",
-    "AddApplicationOutputRequestTypeDef",
-    "AddApplicationReferenceDataSourceRequestTypeDef",
+    "AddApplicationCloudWatchLoggingOptionRequestRequestTypeDef",
+    "AddApplicationInputProcessingConfigurationRequestRequestTypeDef",
+    "AddApplicationInputRequestRequestTypeDef",
+    "AddApplicationOutputRequestRequestTypeDef",
+    "AddApplicationReferenceDataSourceRequestRequestTypeDef",
     "ApplicationDetailTypeDef",
     "ApplicationSummaryTypeDef",
     "ApplicationUpdateTypeDef",
@@ -36,18 +36,18 @@ __all__ = (
     "CloudWatchLoggingOptionDescriptionTypeDef",
     "CloudWatchLoggingOptionTypeDef",
     "CloudWatchLoggingOptionUpdateTypeDef",
-    "CreateApplicationRequestTypeDef",
-    "CreateApplicationResponseResponseTypeDef",
-    "DeleteApplicationCloudWatchLoggingOptionRequestTypeDef",
-    "DeleteApplicationInputProcessingConfigurationRequestTypeDef",
-    "DeleteApplicationOutputRequestTypeDef",
-    "DeleteApplicationReferenceDataSourceRequestTypeDef",
-    "DeleteApplicationRequestTypeDef",
-    "DescribeApplicationRequestTypeDef",
-    "DescribeApplicationResponseResponseTypeDef",
+    "CreateApplicationRequestRequestTypeDef",
+    "CreateApplicationResponseTypeDef",
+    "DeleteApplicationCloudWatchLoggingOptionRequestRequestTypeDef",
+    "DeleteApplicationInputProcessingConfigurationRequestRequestTypeDef",
+    "DeleteApplicationOutputRequestRequestTypeDef",
+    "DeleteApplicationReferenceDataSourceRequestRequestTypeDef",
+    "DeleteApplicationRequestRequestTypeDef",
+    "DescribeApplicationRequestRequestTypeDef",
+    "DescribeApplicationResponseTypeDef",
     "DestinationSchemaTypeDef",
-    "DiscoverInputSchemaRequestTypeDef",
-    "DiscoverInputSchemaResponseResponseTypeDef",
+    "DiscoverInputSchemaRequestRequestTypeDef",
+    "DiscoverInputSchemaResponseTypeDef",
     "InputConfigurationTypeDef",
     "InputDescriptionTypeDef",
     "InputLambdaProcessorDescriptionTypeDef",
@@ -78,10 +78,10 @@ __all__ = (
     "LambdaOutputDescriptionTypeDef",
     "LambdaOutputTypeDef",
     "LambdaOutputUpdateTypeDef",
-    "ListApplicationsRequestTypeDef",
-    "ListApplicationsResponseResponseTypeDef",
-    "ListTagsForResourceRequestTypeDef",
-    "ListTagsForResourceResponseResponseTypeDef",
+    "ListApplicationsRequestRequestTypeDef",
+    "ListApplicationsResponseTypeDef",
+    "ListTagsForResourceRequestRequestTypeDef",
+    "ListTagsForResourceResponseTypeDef",
     "MappingParametersTypeDef",
     "OutputDescriptionTypeDef",
     "OutputTypeDef",
@@ -97,16 +97,16 @@ __all__ = (
     "S3ReferenceDataSourceTypeDef",
     "S3ReferenceDataSourceUpdateTypeDef",
     "SourceSchemaTypeDef",
-    "StartApplicationRequestTypeDef",
-    "StopApplicationRequestTypeDef",
-    "TagResourceRequestTypeDef",
+    "StartApplicationRequestRequestTypeDef",
+    "StopApplicationRequestRequestTypeDef",
+    "TagResourceRequestRequestTypeDef",
     "TagTypeDef",
-    "UntagResourceRequestTypeDef",
-    "UpdateApplicationRequestTypeDef",
+    "UntagResourceRequestRequestTypeDef",
+    "UpdateApplicationRequestRequestTypeDef",
 )
 
-AddApplicationCloudWatchLoggingOptionRequestTypeDef = TypedDict(
-    "AddApplicationCloudWatchLoggingOptionRequestTypeDef",
+AddApplicationCloudWatchLoggingOptionRequestRequestTypeDef = TypedDict(
+    "AddApplicationCloudWatchLoggingOptionRequestRequestTypeDef",
     {
         "ApplicationName": str,
         "CurrentApplicationVersionId": int,
@@ -114,8 +114,8 @@ AddApplicationCloudWatchLoggingOptionRequestTypeDef = TypedDict(
     },
 )
 
-AddApplicationInputProcessingConfigurationRequestTypeDef = TypedDict(
-    "AddApplicationInputProcessingConfigurationRequestTypeDef",
+AddApplicationInputProcessingConfigurationRequestRequestTypeDef = TypedDict(
+    "AddApplicationInputProcessingConfigurationRequestRequestTypeDef",
     {
         "ApplicationName": str,
         "CurrentApplicationVersionId": int,
@@ -124,8 +124,8 @@ AddApplicationInputProcessingConfigurationRequestTypeDef = TypedDict(
     },
 )
 
-AddApplicationInputRequestTypeDef = TypedDict(
-    "AddApplicationInputRequestTypeDef",
+AddApplicationInputRequestRequestTypeDef = TypedDict(
+    "AddApplicationInputRequestRequestTypeDef",
     {
         "ApplicationName": str,
         "CurrentApplicationVersionId": int,
@@ -133,8 +133,8 @@ AddApplicationInputRequestTypeDef = TypedDict(
     },
 )
 
-AddApplicationOutputRequestTypeDef = TypedDict(
-    "AddApplicationOutputRequestTypeDef",
+AddApplicationOutputRequestRequestTypeDef = TypedDict(
+    "AddApplicationOutputRequestRequestTypeDef",
     {
         "ApplicationName": str,
         "CurrentApplicationVersionId": int,
@@ -142,8 +142,8 @@ AddApplicationOutputRequestTypeDef = TypedDict(
     },
 )
 
-AddApplicationReferenceDataSourceRequestTypeDef = TypedDict(
-    "AddApplicationReferenceDataSourceRequestTypeDef",
+AddApplicationReferenceDataSourceRequestRequestTypeDef = TypedDict(
+    "AddApplicationReferenceDataSourceRequestRequestTypeDef",
     {
         "ApplicationName": str,
         "CurrentApplicationVersionId": int,
@@ -264,14 +264,14 @@ class CloudWatchLoggingOptionUpdateTypeDef(
     pass
 
 
-_RequiredCreateApplicationRequestTypeDef = TypedDict(
-    "_RequiredCreateApplicationRequestTypeDef",
+_RequiredCreateApplicationRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateApplicationRequestRequestTypeDef",
     {
         "ApplicationName": str,
     },
 )
-_OptionalCreateApplicationRequestTypeDef = TypedDict(
-    "_OptionalCreateApplicationRequestTypeDef",
+_OptionalCreateApplicationRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateApplicationRequestRequestTypeDef",
     {
         "ApplicationDescription": str,
         "Inputs": List["InputTypeDef"],
@@ -284,22 +284,22 @@ _OptionalCreateApplicationRequestTypeDef = TypedDict(
 )
 
 
-class CreateApplicationRequestTypeDef(
-    _RequiredCreateApplicationRequestTypeDef, _OptionalCreateApplicationRequestTypeDef
+class CreateApplicationRequestRequestTypeDef(
+    _RequiredCreateApplicationRequestRequestTypeDef, _OptionalCreateApplicationRequestRequestTypeDef
 ):
     pass
 
 
-CreateApplicationResponseResponseTypeDef = TypedDict(
-    "CreateApplicationResponseResponseTypeDef",
+CreateApplicationResponseTypeDef = TypedDict(
+    "CreateApplicationResponseTypeDef",
     {
         "ApplicationSummary": "ApplicationSummaryTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-DeleteApplicationCloudWatchLoggingOptionRequestTypeDef = TypedDict(
-    "DeleteApplicationCloudWatchLoggingOptionRequestTypeDef",
+DeleteApplicationCloudWatchLoggingOptionRequestRequestTypeDef = TypedDict(
+    "DeleteApplicationCloudWatchLoggingOptionRequestRequestTypeDef",
     {
         "ApplicationName": str,
         "CurrentApplicationVersionId": int,
@@ -307,8 +307,8 @@ DeleteApplicationCloudWatchLoggingOptionRequestTypeDef = TypedDict(
     },
 )
 
-DeleteApplicationInputProcessingConfigurationRequestTypeDef = TypedDict(
-    "DeleteApplicationInputProcessingConfigurationRequestTypeDef",
+DeleteApplicationInputProcessingConfigurationRequestRequestTypeDef = TypedDict(
+    "DeleteApplicationInputProcessingConfigurationRequestRequestTypeDef",
     {
         "ApplicationName": str,
         "CurrentApplicationVersionId": int,
@@ -316,8 +316,8 @@ DeleteApplicationInputProcessingConfigurationRequestTypeDef = TypedDict(
     },
 )
 
-DeleteApplicationOutputRequestTypeDef = TypedDict(
-    "DeleteApplicationOutputRequestTypeDef",
+DeleteApplicationOutputRequestRequestTypeDef = TypedDict(
+    "DeleteApplicationOutputRequestRequestTypeDef",
     {
         "ApplicationName": str,
         "CurrentApplicationVersionId": int,
@@ -325,8 +325,8 @@ DeleteApplicationOutputRequestTypeDef = TypedDict(
     },
 )
 
-DeleteApplicationReferenceDataSourceRequestTypeDef = TypedDict(
-    "DeleteApplicationReferenceDataSourceRequestTypeDef",
+DeleteApplicationReferenceDataSourceRequestRequestTypeDef = TypedDict(
+    "DeleteApplicationReferenceDataSourceRequestRequestTypeDef",
     {
         "ApplicationName": str,
         "CurrentApplicationVersionId": int,
@@ -334,23 +334,23 @@ DeleteApplicationReferenceDataSourceRequestTypeDef = TypedDict(
     },
 )
 
-DeleteApplicationRequestTypeDef = TypedDict(
-    "DeleteApplicationRequestTypeDef",
+DeleteApplicationRequestRequestTypeDef = TypedDict(
+    "DeleteApplicationRequestRequestTypeDef",
     {
         "ApplicationName": str,
         "CreateTimestamp": Union[datetime, str],
     },
 )
 
-DescribeApplicationRequestTypeDef = TypedDict(
-    "DescribeApplicationRequestTypeDef",
+DescribeApplicationRequestRequestTypeDef = TypedDict(
+    "DescribeApplicationRequestRequestTypeDef",
     {
         "ApplicationName": str,
     },
 )
 
-DescribeApplicationResponseResponseTypeDef = TypedDict(
-    "DescribeApplicationResponseResponseTypeDef",
+DescribeApplicationResponseTypeDef = TypedDict(
+    "DescribeApplicationResponseTypeDef",
     {
         "ApplicationDetail": "ApplicationDetailTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
@@ -364,8 +364,8 @@ DestinationSchemaTypeDef = TypedDict(
     },
 )
 
-DiscoverInputSchemaRequestTypeDef = TypedDict(
-    "DiscoverInputSchemaRequestTypeDef",
+DiscoverInputSchemaRequestRequestTypeDef = TypedDict(
+    "DiscoverInputSchemaRequestRequestTypeDef",
     {
         "ResourceARN": str,
         "RoleARN": str,
@@ -376,8 +376,8 @@ DiscoverInputSchemaRequestTypeDef = TypedDict(
     total=False,
 )
 
-DiscoverInputSchemaResponseResponseTypeDef = TypedDict(
-    "DiscoverInputSchemaResponseResponseTypeDef",
+DiscoverInputSchemaResponseTypeDef = TypedDict(
+    "DiscoverInputSchemaResponseTypeDef",
     {
         "InputSchema": "SourceSchemaTypeDef",
         "ParsedInputRecords": List[List[str]],
@@ -677,8 +677,8 @@ LambdaOutputUpdateTypeDef = TypedDict(
     total=False,
 )
 
-ListApplicationsRequestTypeDef = TypedDict(
-    "ListApplicationsRequestTypeDef",
+ListApplicationsRequestRequestTypeDef = TypedDict(
+    "ListApplicationsRequestRequestTypeDef",
     {
         "Limit": int,
         "ExclusiveStartApplicationName": str,
@@ -686,8 +686,8 @@ ListApplicationsRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListApplicationsResponseResponseTypeDef = TypedDict(
-    "ListApplicationsResponseResponseTypeDef",
+ListApplicationsResponseTypeDef = TypedDict(
+    "ListApplicationsResponseTypeDef",
     {
         "ApplicationSummaries": List["ApplicationSummaryTypeDef"],
         "HasMoreApplications": bool,
@@ -695,15 +695,15 @@ ListApplicationsResponseResponseTypeDef = TypedDict(
     },
 )
 
-ListTagsForResourceRequestTypeDef = TypedDict(
-    "ListTagsForResourceRequestTypeDef",
+ListTagsForResourceRequestRequestTypeDef = TypedDict(
+    "ListTagsForResourceRequestRequestTypeDef",
     {
         "ResourceARN": str,
     },
 )
 
-ListTagsForResourceResponseResponseTypeDef = TypedDict(
-    "ListTagsForResourceResponseResponseTypeDef",
+ListTagsForResourceResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseTypeDef",
     {
         "Tags": List["TagTypeDef"],
         "ResponseMetadata": "ResponseMetadataTypeDef",
@@ -952,23 +952,23 @@ class SourceSchemaTypeDef(_RequiredSourceSchemaTypeDef, _OptionalSourceSchemaTyp
     pass
 
 
-StartApplicationRequestTypeDef = TypedDict(
-    "StartApplicationRequestTypeDef",
+StartApplicationRequestRequestTypeDef = TypedDict(
+    "StartApplicationRequestRequestTypeDef",
     {
         "ApplicationName": str,
         "InputConfigurations": List["InputConfigurationTypeDef"],
     },
 )
 
-StopApplicationRequestTypeDef = TypedDict(
-    "StopApplicationRequestTypeDef",
+StopApplicationRequestRequestTypeDef = TypedDict(
+    "StopApplicationRequestRequestTypeDef",
     {
         "ApplicationName": str,
     },
 )
 
-TagResourceRequestTypeDef = TypedDict(
-    "TagResourceRequestTypeDef",
+TagResourceRequestRequestTypeDef = TypedDict(
+    "TagResourceRequestRequestTypeDef",
     {
         "ResourceARN": str,
         "Tags": List["TagTypeDef"],
@@ -994,16 +994,16 @@ class TagTypeDef(_RequiredTagTypeDef, _OptionalTagTypeDef):
     pass
 
 
-UntagResourceRequestTypeDef = TypedDict(
-    "UntagResourceRequestTypeDef",
+UntagResourceRequestRequestTypeDef = TypedDict(
+    "UntagResourceRequestRequestTypeDef",
     {
         "ResourceARN": str,
         "TagKeys": List[str],
     },
 )
 
-UpdateApplicationRequestTypeDef = TypedDict(
-    "UpdateApplicationRequestTypeDef",
+UpdateApplicationRequestRequestTypeDef = TypedDict(
+    "UpdateApplicationRequestRequestTypeDef",
     {
         "ApplicationName": str,
         "CurrentApplicationVersionId": int,
